@@ -5,6 +5,9 @@ ORDER.default <- function(x, ..., na.last = TRUE, decreasing = FALSE)
   order(x, ..., na.last = na.last, decreasing = decreasing)
 
 ORDER.timeDate <- function(x, ...) {
-  stopifnot(require("timeDate"))
   order(as.POSIXct(x), ...)
 }
+
+ORDER.chron <- ORDER.dates <- ORDER.times <- function(x, ...) {
+  order(as.numeric(x), ...)
+}
