@@ -5,7 +5,8 @@ rbind.zoo <- function(..., deparse.level = 1)
   indexes <- do.call("c", unname(lapply(args, index)))
 
   my.table <- function(x) {
-    x <- x[ORDER(x)]
+    ix <- ORDER(x)
+    x <- x[ix]
     table(MATCH(x,x))
   }
   if(max(my.table(indexes)) > 1L) stop("indexes overlap")
@@ -90,7 +91,7 @@ merge.zoo <- function(..., all = TRUE, fill = NA, suffixes = NULL, check.names =
     parent <- parent.frame()
 
     is.plain <- function(x) 
-	all(class(x) %in% c("array", "integer", "numeric", "factor", "matrix", "logical"))
+	all(class(x) %in% c("array", "integer", "numeric", "factor", "matrix", "logical", "character"))
 
     is.scalar <- function(x) is.plain(x) && length(x) == 1
 
@@ -149,21 +150,30 @@ merge.zoo <- function(..., all = TRUE, fill = NA, suffixes = NULL, check.names =
       stop("series cannot be merged with non-unique index entries in a series")
     ## 2. for differing classes
     indexclasses <- sapply(indexlist, function(x) class(x)[1])
-    if (!all(indexclasses == indexclasses[1])) 
+    if (!all(indexclasses == indexclasses[1L])) {
         warning(paste("Index vectors are of different classes:", 
             paste(indexclasses, collapse = " ")))
+	if(all(indexclasses %in% c("numeric", "integer"))) {
+	    indexlist <- lapply(indexlist, as.numeric)
+	} else if(all(vapply(indexlist, function(e) inherits(e, "Date") || is.numeric(e), NA))) {
+            indexlist <- lapply(indexlist, as.Date)
+	}
+    }
 
     # fn to get the unique elements in x, in sorted order, using only
     # [, match, length and order
     sort.unique <- function(x) {
-        x <- x[MATCH(x, x) == seq_len(length(x))]
-        x[ORDER(x)]
+        ix <- MATCH(x, x) == seq_len(length(x))
+	x <- x[ix]
+        ix <- ORDER(x)
+        x[ix]
     }
 
     # fn to get intersection of each element in list of lists
     intersect.list <- function(list) { 
         my.table <- function(x) {
-           x <- x[ORDER(x)]
+	   ix <- ORDER(x)
+           x <- x[ix]
            table(MATCH(x, x))
 	}
 	union <- do.call("c", unname(list))
@@ -316,7 +326,7 @@ merge.zoo <- function(..., all = TRUE, fill = NA, suffixes = NULL, check.names =
             # if (length(a) == 0) 
             #   return(NULL)
             if (length(dim(a)) ==0) {
-                return("")
+                if (length(a) == 0) return(NULL) else return("")
             } else {
 				if (ncol(a) == 0) return(NULL)
                 rval <- colnames(a)
